import vpython
from vpython import color, vector

# don't automatically zoom out to keep everything in view
vpython.scene.autoscale = False

# create the ball and two walls
# specify color, radius (for the ball), size (for the boxes), and initial position
ball = vpython.sphere(radius=0.5, color=color.cyan)
wallR = vpython.box(pos=vector(6, 0, 0), size=vector(0.2, 12, 12),
                    color=color.green)
wallL = vpython.box(pos=vector(-6, 0, 0), size=vector(0.2, 12, 12),
                    color=color.red)

# initialize a trail to show where the ball has been
ball.trail = vpython.curve(color=ball.color)

ball.velocity = vector(25, 5, 0)

# arrow to show the ball's velocity
varr = vpython.arrow(pos=ball.pos, axis=0.1*ball.velocity, color=color.yellow)

deltat = 0.005
t = 0
while t < 5:
    vpython.rate(50) # controls how many times we go around this loop per second
    ball.pos = ball.pos + ball.velocity * deltat # update the ball's position
    ball.trail.append(pos=ball.pos) # update the ball's trail

    # check if the ball has collided with either wall
    # if so, have it switch directions
    if ball.pos.x > wallR.pos.x:
        ball.velocity.x = -ball.velocity.x
    if ball.pos.x < wallL.pos.x:
        ball.velocity.x = -ball.velocity.x

    # update the velocity arrow
    varr.pos = ball.pos
    varr.axis = 0.1*ball.velocity
